@@ -5,11 +5,13 @@
 # CREATED: 02/06/14 01:48:56 by Kent Fredric (kentnl) <kentfredric@gmail.com>
 # ABSTRACT: Write an INI file from a bundle
 
-use 5.008;    #utf8
+use 5.008;    # utf8
 use strict;
 use warnings;
 use utf8;
 
+our $VERSION = 0.001;
+
 use Carp qw( croak carp );
 use Perl::Critic::ProfileCompiler::Util qw( create_bundle );
 use Path::Tiny qw(path);
@@ -41,7 +43,10 @@ my $config = $inf->apply_config;
 }
 my $deps = $inf->own_deps;
 {
-  my $depsfile = path('./perlcritic.deps')->openw_utf8;
+  my $target = path('./misc');
+  $target->mkpath if not $target->is_dir;
+
+  my $depsfile = $target->child('perlcritic.deps')->openw_utf8;
   for my $key ( sort keys %{$deps} ) {
     $depsfile->printf( "%s~%s\n", $key, $deps->{$key} );
     *STDERR->printf( "%s => %s\n", $key, $deps->{$key} );
